==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Classification/group__PkgClassificationMesh.js <==
var group__PkgClassificationMesh =
[
    [ "Mesh_feature_generator", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html", [
      [ "Iso_cuboid_3", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a0a25aad5a8dac6a08786f7810e1b1f73", null ],
      [ "Local_eigen_analysis", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#ae1dab04ca894f3899a649e4bf79060e4", null ],
      [ "Neighborhood", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a315419607b3b5a01f00316d55127587e", null ],
      [ "Planimetric_grid", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a2a36b8f53da2f3f111b80184f3c465dd", null ],
      [ "Mesh_feature_generator", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#afdefaad53592b29e4c3f38b6b2666121", null ],
      [ "bbox", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a4fb568b8b8c31bf043d1142b20c3be36", null ],
      [ "eigen", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#af59594fe2f32e66896896b530a47e9fb", null ],
      [ "generate_face_based_features", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a9651d0485d3af616ef4b19a2ac1111ae", null ],
      [ "generate_point_based_features", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a654102f5802627ab1b6bb515a0b340d3", null ],
      [ "grid", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a5b549636aeedb58a47439fa04ba67070", null ],
      [ "grid_resolution", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a85bb15af4ef06d238332d9c4c028a786", null ],
      [ "neighborhood", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a8e628189f4d49e021607908f1dddeae3", null ],
      [ "number_of_scales", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#acea616624fc80748230b5b5efb9321b8", null ],
      [ "radius_dtm", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a61f5d8881ac71e0ca857d8a63f718cfa", null ],
      [ "radius_neighbors", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a418e62700e20cfb51a0ca34e34a95935", null ]
    ] ],
    [ "Mesh_neighborhood", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html", [
      [ "N_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1N__ring__neighbor__query.html", [
        [ "value_type", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1N__ring__neighbor__query.html#a9cdace9d3d13c1f502bfd260835f231f", null ],
        [ "N_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1N__ring__neighbor__query.html#aea3a9cbb1d6a20a796bbfac88180848b", null ]
      ] ],
      [ "One_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1One__ring__neighbor__query.html", [
        [ "value_type", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1One__ring__neighbor__query.html#ab8f0c2c4c317f7e86cfd866c304302f9", null ],
        [ "One_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1One__ring__neighbor__query.html#a7185145ff70cdbf92ad892fb9b201dd6", null ]
      ] ],
      [ "face_descriptor", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html#a3907cad707bed1dfa4ff6a2f0cb17b35", null ],
      [ "Mesh_neighborhood", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html#aef42d5022e05cb01ad1a2abcb083e499", null ],
      [ "n_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html#a13b493ddd802272733dcc7242cd1ed36", null ],
      [ "one_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html#a802e7cead81654ff24fcb4813a790e85", null ]
    ] ],
    [ "Face_descriptor_to_center_of_mass_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html", [
      [ "category", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a84e7d9dec557ada14f9c96ce01d2d67b", null ],
      [ "key_type", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#aa08ec19fe3c95a96fe0b8a37191143b3", null ],
      [ "Point_3", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a794cdb423ee618938a63934c7bb40fd2", null ],
      [ "reference", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#afe4ae867173c736d79df5c7f96c74d44", null ],
      [ "value_type", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#ade2278edb38d8dcd5bfed43545b0f6c0", null ],
      [ "Face_descriptor_to_center_of_mass_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a0d776b3e0b6026a480cdef57012acb51", null ],
      [ "Face_descriptor_to_center_of_mass_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a4ae809d50dd49260915ec1188dbe3740", null ],
      [ "Face_descriptor_to_center_of_mass_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a2db47bc9710c177ead3dc5a8f9a06823", null ]
    ] ],
    [ "Face_descriptor_to_face_descriptor_with_bbox_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html", [
      [ "face_descriptor_with_bbox", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map_1_1face__descriptor__with__bbox.html", [
        [ "face_descriptor_with_bbox", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map_1_1face__descriptor__with__bbox.html#a5fdac202ff3f3bdb7721a56258b19d11", null ],
        [ "bbox", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map_1_1face__descriptor__with__bbox.html#a587ebd8794580d98f57ad5d7a9dab982", null ],
        [ "operator face_descriptor", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map_1_1face__descriptor__with__bbox.html#ada03a74a45c0ae0e38de143ba26bd654", null ]
      ] ],
      [ "category", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#a12a6fbd4cdc7cdba2a8d3672e4b2890c", null ],
      [ "face_descriptor", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#ac91929aa4f058cfe3f5a0c2a07de9db1", null ],
      [ "key_type", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#a6b13a9b9c0fa500329519ff35de64673", null ],
      [ "reference", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#ae930c4f594801bfbe51ef6a570ea01d4", null ],
      [ "value_type", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#ace0dceb71b7848ee8cae4c72fe8b0fcf", null ],
      [ "Face_descriptor_to_face_descriptor_with_bbox_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#a88d2ca8e27d216b561b57f12a75d08b7", null ],
      [ "Face_descriptor_to_face_descriptor_with_bbox_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#ad10bf9f7ee38e818516354736839a72a", null ],
      [ "Face_descriptor_to_face_descriptor_with_bbox_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#a0e4fa15ef698eb442bc3dc5cb65d259b", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Classification/group__PkgClassificationMesh.js <==
var group__PkgClassificationMesh =
[
    [ "CGAL::Classification::Mesh_feature_generator< GeomTraits, FaceListGraph, PointMap, ConcurrencyTag, DiagonalizeTraits >", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html", [
      [ "Iso_cuboid_3", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a0a25aad5a8dac6a08786f7810e1b1f73", null ],
      [ "Local_eigen_analysis", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#ae1dab04ca894f3899a649e4bf79060e4", null ],
      [ "Neighborhood", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a315419607b3b5a01f00316d55127587e", null ],
      [ "Planimetric_grid", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a2a36b8f53da2f3f111b80184f3c465dd", null ],
      [ "Mesh_feature_generator", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#afdefaad53592b29e4c3f38b6b2666121", null ],
      [ "bbox", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#adb4395d3961dffefe7a9e588982baf9b", null ],
      [ "eigen", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a26b78ee11dbcb84193433fd97360def1", null ],
      [ "generate_face_based_features", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a9651d0485d3af616ef4b19a2ac1111ae", null ],
      [ "generate_point_based_features", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a654102f5802627ab1b6bb515a0b340d3", null ],
      [ "grid", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#aee67ee64282da1a1accae79156c0aafd", null ],
      [ "grid_resolution", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a85bb15af4ef06d238332d9c4c028a786", null ],
      [ "neighborhood", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a85ca31be6bdead9520e9b3ccbae92861", null ],
      [ "number_of_scales", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#acea616624fc80748230b5b5efb9321b8", null ],
      [ "radius_dtm", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a61f5d8881ac71e0ca857d8a63f718cfa", null ],
      [ "radius_neighbors", "classCGAL_1_1Classification_1_1Mesh__feature__generator.html#a418e62700e20cfb51a0ca34e34a95935", null ]
    ] ],
    [ "CGAL::Classification::Mesh_neighborhood< FaceListGraph >", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html", [
      [ "N_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1N__ring__neighbor__query.html", [
        [ "value_type", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1N__ring__neighbor__query.html#a9cdace9d3d13c1f502bfd260835f231f", null ],
        [ "N_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1N__ring__neighbor__query.html#aea3a9cbb1d6a20a796bbfac88180848b", null ]
      ] ],
      [ "One_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1One__ring__neighbor__query.html", [
        [ "value_type", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1One__ring__neighbor__query.html#ab8f0c2c4c317f7e86cfd866c304302f9", null ],
        [ "One_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood_1_1One__ring__neighbor__query.html#a7185145ff70cdbf92ad892fb9b201dd6", null ]
      ] ],
      [ "face_descriptor", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html#a3907cad707bed1dfa4ff6a2f0cb17b35", null ],
      [ "Mesh_neighborhood", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html#aef42d5022e05cb01ad1a2abcb083e499", null ],
      [ "n_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html#a13b493ddd802272733dcc7242cd1ed36", null ],
      [ "one_ring_neighbor_query", "classCGAL_1_1Classification_1_1Mesh__neighborhood.html#a802e7cead81654ff24fcb4813a790e85", null ]
    ] ],
    [ "CGAL::Classification::Face_descriptor_to_center_of_mass_map< FaceGraph, VertexPointMap >", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html", [
      [ "category", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a84e7d9dec557ada14f9c96ce01d2d67b", null ],
      [ "key_type", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#aa08ec19fe3c95a96fe0b8a37191143b3", null ],
      [ "Point_3", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a794cdb423ee618938a63934c7bb40fd2", null ],
      [ "reference", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#afe4ae867173c736d79df5c7f96c74d44", null ],
      [ "value_type", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#ade2278edb38d8dcd5bfed43545b0f6c0", null ],
      [ "Face_descriptor_to_center_of_mass_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a0d776b3e0b6026a480cdef57012acb51", null ],
      [ "Face_descriptor_to_center_of_mass_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a4ae809d50dd49260915ec1188dbe3740", null ],
      [ "Face_descriptor_to_center_of_mass_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__center__of__mass__map.html#a2db47bc9710c177ead3dc5a8f9a06823", null ]
    ] ],
    [ "CGAL::Classification::Face_descriptor_to_face_descriptor_with_bbox_map< FaceGraph, VertexPointMap >", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html", [
      [ "face_descriptor_with_bbox", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map_1_1face__descriptor__with__bbox.html", [
        [ "face_descriptor_with_bbox", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map_1_1face__descriptor__with__bbox.html#a5fdac202ff3f3bdb7721a56258b19d11", null ],
        [ "bbox", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map_1_1face__descriptor__with__bbox.html#a587ebd8794580d98f57ad5d7a9dab982", null ],
        [ "operator face_descriptor", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map_1_1face__descriptor__with__bbox.html#ada03a74a45c0ae0e38de143ba26bd654", null ]
      ] ],
      [ "category", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#a12a6fbd4cdc7cdba2a8d3672e4b2890c", null ],
      [ "face_descriptor", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#ac91929aa4f058cfe3f5a0c2a07de9db1", null ],
      [ "key_type", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#a6b13a9b9c0fa500329519ff35de64673", null ],
      [ "reference", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#ae930c4f594801bfbe51ef6a570ea01d4", null ],
      [ "value_type", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#ace0dceb71b7848ee8cae4c72fe8b0fcf", null ],
      [ "Face_descriptor_to_face_descriptor_with_bbox_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#a88d2ca8e27d216b561b57f12a75d08b7", null ],
      [ "Face_descriptor_to_face_descriptor_with_bbox_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#ad10bf9f7ee38e818516354736839a72a", null ],
      [ "Face_descriptor_to_face_descriptor_with_bbox_map", "classCGAL_1_1Classification_1_1Face__descriptor__to__face__descriptor__with__bbox__map.html#a0e4fa15ef698eb442bc3dc5cb65d259b", null ]
    ] ]
];
